@@ -204,8 +204,7 @@ fn get_files_in_dir(paths: &mut Vec<PathBuf>, path: PathBuf) {
                 vec![path]
             }
             Ok(d) => d
-                .filter(std::result::Result::is_ok)
-                .map(|entry| entry.unwrap().path())
+                .filter_map(|entry| entry.ok().map(|e| e.path()))
                 .collect::<Vec<PathBuf>>(),
         }
     } else {
@@ -450,7 +449,6 @@ impl<'args> Exa<'args> {
             }
 
             (Mode::GridDetails(ref opts), Some(console_width)) => {
-                let grid = &opts.grid;
                 let details = &opts.details;
                 let row_threshold = opts.row_threshold;
 
@@ -464,7 +462,6 @@ impl<'args> Exa<'args> {
                     files,
                     theme,
                     file_style,
-                    grid,
                     details,
                     filter,
                     row_threshold,
